==> core-android-debug-1.34.2-sources.jar: commonMain/io/dyte/core/listeners/DyteSelfEventsListener.kt <==
package io.dyte.core.listeners

import io.dyte.core.controllers.DyteStageStatus
import io.dyte.core.models.DyteSelfParticipant
import io.dyte.core.models.DyteVideoDevice
import io.dyte.core.models.WaitListStatus
import io.dyte.core.network.info.SelfPermissions

/**
 * Dyte self events listener
 *
 * You can subscribe to all self events by implementing this interface. To subscribe pass
 * implementation to [io.dyte.core.DyteMobileClient.addSelfEventsListener]
 *
 * @constructor Create empty Dyte self events listener
 */
// TODO : device change callback.
interface DyteSelfEventsListener : ExternalEventListener {

  fun onMeetingRoomJoinedWithoutCameraPermission() {}

  fun onMeetingRoomJoinedWithoutMicPermission() {}

  /**
   * Audio update
   *
   * when this participant mutes/un-mutes their audio Also triggered when host toggles audio for
   * this participant
   *
   * @param audioEnabled : true if audio is enabled, false otherwise
   */
  fun onAudioUpdate(audioEnabled: Boolean) {}

  /**
   * Video update
   *
   * when this participant mutes/un-mutes their video. Also triggered when host toggles video for
   * this participant
   *
   * @param videoEnabled : true if video is enabled, false otherwisee
   */
  fun onVideoUpdate(videoEnabled: Boolean) {}

  fun onAudioDevicesUpdated() {}

  fun onVideoDeviceChanged(videoDevice: DyteVideoDevice) {}

  fun onProximityChanged(isNear: Boolean) {}

  fun onWaitListStatusUpdate(waitListStatus: WaitListStatus) {}

  // called whenever audio/video is updated
  fun onUpdate(participant: DyteSelfParticipant) {}

  /** triggered when host kick this participant or kick all. */
  fun onRemovedFromMeeting() {}

  @Deprecated("Please use DyteStageEventListener.onStageStatusUpdated()")
  fun onStageStatusUpdated(stageStatus: DyteStageStatus) {}

  fun onRoomMessage(type: String, payload: Map<String, *>) {}

  fun onScreenShareStarted() {}

  fun onScreenShareStartFailed(reason: String = "unknown") {}

  fun onScreenShareStopped() {}

  fun onPermissionsUpdated(permission: SelfPermissions) {}
}

==> core-android-debug-1.36.1-sources.jar: commonMain/io/dyte/core/listeners/DyteSelfEventsListener.kt <==
package io.dyte.core.listeners

import io.dyte.core.controllers.DyteStageStatus
import io.dyte.core.models.DyteSelfParticipant
import io.dyte.core.models.DyteVideoDevice
import io.dyte.core.models.WaitListStatus
import io.dyte.core.network.info.SelfPermissions

/**
 * Dyte self events listener
 *
 * You can subscribe to all self events by implementing this interface. To subscribe pass
 * implementation to [io.dyte.core.DyteMobileClient.addSelfEventsListener]
 *
 * @constructor Create empty Dyte self events listener
 */
// TODO : device change callback.
interface DyteSelfEventsListener : ExternalEventListener {

  fun onMeetingRoomJoinedWithoutCameraPermission() {}

  fun onMeetingRoomJoinedWithoutMicPermission() {}

  /**
   * Audio update
   *
   * when this participant mutes/un-mutes their audio Also triggered when host toggles audio for
   * this participant
   *
   * @param audioEnabled : true if audio is enabled, false otherwise
   */
  fun onAudioUpdate(audioEnabled: Boolean) {}

  /**
   * Video update
   *
   * when this participant mutes/un-mutes their video. Also triggered when host toggles video for
   * this participant
   *
   * @param videoEnabled : true if video is enabled, false otherwisee
   */
  fun onVideoUpdate(videoEnabled: Boolean) {}

  fun onAudioDevicesUpdated() {}

  fun onVideoDeviceChanged(videoDevice: DyteVideoDevice) {}

  fun onProximityChanged(isNear: Boolean) {}

  fun onWaitListStatusUpdate(waitListStatus: WaitListStatus) {}

  // called whenever audio/video is updated
  fun onUpdate(participant: DyteSelfParticipant) {}

  /** triggered when host kick this participant. */
  fun onRemovedFromMeeting() {}

  @Deprecated("Please use DyteStageEventListener.onStageStatusUpdated()")
  fun onStageStatusUpdated(stageStatus: DyteStageStatus) {}

  fun onRoomMessage(type: String, payload: Map<String, *>) {}

  fun onScreenShareStarted() {}

  fun onScreenShareStartFailed(reason: String = "unknown") {}

  fun onScreenShareStopped() {}

  fun onPermissionsUpdated(permission: SelfPermissions) {}
}
